#!/bin/bash
#################################################################
# ZW3B-SITE - Version 5.8.2 : 2015/11/03
#
# Author : Olivier Romain Jaillet (at) LAB3W alias Kss* (at) ZW3B
#
# Contact : www.zw3b.fr - www.lab3w.fr
#################################################################

#####-------------------------- CHECK ----------------------------#####
ID=`id -u`

if [ "x$ID" != "x0" ]; then
	echo "Run as root!"
	exit 1
fi

EXPECTED_ARGS=3
E_BADARGS=65

if [ $# -ne $EXPECTED_ARGS ]
then
	echo “Usage: `basename $0` install domain.tld www”
	exit $E_BADARGS
fi

#####-------------------------- /CHECK ----------------------------#####

#####-------------------------- DECLARATION ----------------------------#####
MYDIR=`dirname $0`

# Date Actuelle
DATE=`date +%Y%m%d`
DATEFR="2015/09/25 12:39:28"
DATEFR=`date +"%Y/%m/%d %H:%M:%S"`

# Envoie
DOMAIN=$2
VHOST=$3

# Repertoires APPs
ZW3B_BASE="/var/pro/web_apps/zw3b/5.8.2/"
ZW3B_LN="../../../../web_apps/zw3b/5.8.2/"
ZW3B_TREE="/var/pro/web_apps/zw3b-tree/zwsite-v5.zw3b.fr/"

#
ZW3B_PATH_LIB="lib/"
ZW3B_PATH_SHARE="share/"

ZW3B_PATH_INSTALL="setup/"
ZW3B_PATH_SYS="sys/"
ZW3B_PATH_THEMES="skins/"
ZW3B_PATH_VAR="var/"
ZW3B_PATH_TMP="tmp/"

#####-------------------------- /DECLARATION ----------------------------#####

#####-------------------------- FONCTIONS ----------------------------#####

## CONFIGURATION DU SITE ################################################
function configuration()
{

    echo "#########################################################################################";
    echo "#### Creation du ZW3B.Site '"$VHOST.$DOMAIN"'"
    
    echo "";
    echo "Configuration : ";
    echo "" ;
    
    ## TITLE SITE #######
    ZW3BSITE=`echo $VHOST.$DOMAIN | tr '[:lower:]' '[:upper:]'`
    
    default_name="ZW3B.Site : $ZW3BSITE"
    echo -n "   Nom du site  [${default_name}] : "; read name;
    if [ "${name}" == "" ];
    then
        name="${default_name}";
    fi
    
    ## DESCIPTION SITE #######
    default_desc="ZW3B.Site &copy; `date +%Y` - $ZW3BSITE - Generated with ZW3B 5.8.2 : Web Sites Management System"
    echo -n "   Description [${default_desc}] : "; read desc;
    if [ "${desc}" == "" ];
    then
        desc="${default_desc}";
    fi
       
    ## MAIL CONTACT #######
    default_creator="O.Romain Jaillet-Ramey alias LAB3W.ORJ"
    echo -n "   Createur [${default_creator}] : "; read creator;
    if [ "${creator}" == "" ];
    then
        creator="${default_creator}";
    fi
 
    ## MAIL CONTACT #######   
    default_mail="roots@zw3b.fr"
    echo -n "   Mail contact [${default_mail}] : "; read mail;
    if [ "${mail}" == "" ];
    then
        mail="${default_mail}";
    fi
}

## ZW3B_PATH_THEMES DU SITE #################################################
function selection_theme()
{
    
    echo "";
    echo "   Liste des Skins : "; #echo ${ZW3B_BASE}${ZW3B_PATH_THEMES}

    # Liste des dossier des themes
    i=1
    declare -a tab;
    cd  ${ZW3B_BASE}${ZW3B_PATH_THEMES} ; set * ; #echo $@
    for theme in $@
     do
        if [ -d "${ZW3B_BASE}${ZW3B_PATH_THEMES}/${theme}" ] 
        then
            tab[$i]=$theme;
            echo "        $i) $theme";
            i=$(($i + 1))
        fi
    done
    echo "";
    
    # Config. du theme
    default_theme=4;   
    echo -n "   Selection du skin [$default_theme] : "; read theme_choix
    if [ "${theme_choix}" == "" ];
    then
        theme_choix="${default_theme}";
    #else
    #    choix=`echo $theme_choix | cut -d\' -f1`
    fi
    
    theme=${tab[${theme_choix}]};
}


## MODELE DE PAGE #################################################
function selection_model()
{

    echo "";
    echo "   Liste des Modeles de page : "; #echo ${ZW3B_BASE}${ZW3B_PATH_THEMES}

    # Liste des dossier des modeles
    i=1
    declare -a tab
    cd ${ZW3B_BASE}${ZW3B_PATH_VAR}zones/ ; set * ; #echo $@
    for model in $@
     do
        if [ -f "${ZW3B_BASE}${ZW3B_PATH_VAR}zones/${model}" ]
        then
            tab[$i]=$model;
            echo "        $i) $model";
            i=$(($i + 1))
        fi
    done
    echo "";

   # Config. du modele
    default_model=16;
    echo -n "   Selection du modele de page [$default_model] : "; read model_choix
    if [ "${model_choix}" == "" ];
    then
        model_choix="${default_model}";
    #else
    #    choix=`echo $theme_choix | cut -d\' -f1`
    fi

    model=${tab[${model_choix}]};
}



## MODULES DU SITE ################################################
function selection_modules()
{
    echo "";
    echo "   Selection des modules : NaN"
}

## DESCRIPTION DE L'ZW3B_PATH_INSTALL #######################################
function configuration_check()
{
    documentRoot="/var/pro/web_sites/${DOMAIN}/${VHOST}/web/";
    logsRoot="/var/pro/web_logs/${DOMAIN}/${VHOST}/logs/";
    url=${VHOST}.${DOMAIN};
    
    echo "";
    echo "Description de l'installation : ";
    echo "";
    echo "   URL du site   : http://${url}";
    echo "   Nom du site   : ${name}";
    echo "   Description   : ${desc}";
    echo "   Mail contact  : ${mail}";
    echo "   Skin du site : ${theme}";
    echo "   Model de page : ${model}";
    echo "   DocumentRoot  : ${documentRoot}";
    echo "   LogsRoot      : ${logsRoot}";
    #echo "   Rubriques     : ${rub}";
    
    echo "";
    echo -n "Valider de la configuration (Oui pour lancer l'install) : ";
    read valid;
    
    echo "";
    
    case $valid in
    o|O|oui|Oui|y|Y|yes|Yes )
          echo "Lancement de l'installation..........."
          echo "" ;
    	 ;;
    n|N|non|Non|no|No )
          echo "------------> Arret de l'installation !"
          echo "#########################################################################################";
          exit;
    	 ;;
    *)
       echo "------------> Arret de l'installation !"
       echo "#########################################################################################";
       exit;
    ;;
    esac
}



## ZW3B_PATH_INSTALL #######################################
function install_default()
{
    # Creation du repertoire racine web
    echo -n 'Creation du repertoire racine :'
    echo ' '${documentRoot}
    /bin/mkdir -p ${documentRoot}
    #echo "";
    # Creation du repertoire racine logs
    echo -n 'Creation du repertoire des logs :'
    echo -n ' '${logsRoot}
    /bin/mkdir -p ${logsRoot}
    echo "" ; 
    # on copie le dossier install
    echo "";
#    echo 'Creation du dossier                       ./setup/'
#    /bin/cp -Rp ${ZW3B_BASE}${ZW3B_PATH_INSTALL} ${documentRoot}
    # on copie les fichiers racine (temporaire)
    echo "";
    echo 'Copie du fichier                       ./.htaccess'
    /bin/cp -Rp ${ZW3B_BASE}/.htaccess ${documentRoot}/.htaccess
    echo "";
    echo 'Copie du fichier                       ./index.php'
    /bin/cp -Rp ${ZW3B_BASE}/index.php ${documentRoot}/index.php
}   
function install_default_ln()
{               
    # on creait les liens symboliques
    echo ""; 
    echo 'Creation du lien symbolique                       ./lib/'
    /bin/ln -snf ${ZW3B_LN}${ZW3B_PATH_LIB} ${documentRoot}/lib
    echo 'Creation du lien symbolique                       ./setup/'
    /bin/ln -snf ${ZW3B_LN}${ZW3B_PATH_LIB} ${documentRoot}/setup
    echo 'Creation du lien symbolique                       ./share/'
    /bin/ln -snf ${ZW3B_LN}${ZW3B_PATH_SHARE} ${documentRoot}/share
    echo 'Creation du lien symbolique                       ./sys/' 
    /bin/ln -snf ${ZW3B_LN}${ZW3B_PATH_SYS} ${documentRoot}/sys
    echo 'Creation du lien symbolique                       ./skins/' 
    /bin/ln -snf ${ZW3B_LN}${ZW3B_PATH_THEMES} ${documentRoot}/skins
  
}    

function install_default_tmp()
{
    # on creait le repertoire temporaire
    echo "";
    echo 'Creation du repertoire temporaire en ecriture     ./tmp/'
    /bin/mkdir ${documentRoot}/tmp/ && /bin/chmod 777 ${documentRoot}/tmp/  
}

function install_default_var()
{
    # on creait le repertoire des datas
    echo "";
    echo 'Creation du repertoire des donnees                ./var/'
    /bin/mkdir ${documentRoot}/var/
    /bin/chown kss.www-data ${documentRoot}/var/
    /bin/chmod g+w ${documentRoot}/var/

    # users
    echo ""
    echo "Copy du repertoire usr default                    ./var/usr/"
    /bin/cp -Rp ${ZW3B_BASE}var/usr/ ${documentRoot}/var/
    /bin/chown kss.www-data ${documentRoot}/var/usr/
    /bin/chmod g+w ${documentRoot}/var/usr/

    # zones
    echo "";
    echo "Creation du lien symbolique                       ./var/zones/"
    /bin/ln -snf ../${ZW3B_LN}var/zones/ ${documentRoot}/var/zones

#    echo 'Creation du repertoire des donnees en ecriture    ./var/contents/docs/'
#    mkdir ${documentRoot}/var/doc/ && chmod 777 ${documentRoot}/var/contents/docs/
#    echo 'Creation du repertoire des donnees en ecriture    ./var/contents/news/'
#    mkdir ${documentRoot}/var/img/ && chmod 777 ${documentRoot}./var/contents/news/
#    echo 'Creation du repertoire des donnees en ecriture    ./var/pub/'
#    mkdir ${documentRoot}/var/pub/ && chmod 777 ${documentRoot}/var/pub/
#    echo 'Creation du repertoire des donnees en ecriture    ./var/rss/'
#    mkdir ${documentRoot}/var/rss/ && chmod 777 ${documentRoot}/var/rss/
#    echo 'Creation du repertoire des donnees en ecriture    ./var/xml/'
#    mkdir ${documentRoot}/var/xml/ && chmod 777 ${documentRoot}/var/xml/
#    echo 'Creation du repertoire des donnees en ecriture    ./var/tree/'
#    mkdir ${documentRoot}/var/tree/ && chmod 777 ${documentRoot}/var/tree/
#    echo 'Creation du repertoire des donnees en ecriture    ./var/usr/'
#    mkdir ${documentRoot}/var/usr/ && chmod 777 ${documentRoot}/var/usr/


}

function install_default_tree_info()
{

    # on creait le repertoire des datas
    echo "";
    echo 'Creation du repertoire des donnees de larbre      ./var/tree/'
    /bin/mkdir -p ${documentRoot}/var/tree/${url}
    /bin/chown -R kss.www-data ${documentRoot}/var/tree/
    /bin/chmod -R g+w ${documentRoot}/var/tree/

    # on crée le fichier des infos du repertoire par default
    file=info.gen.php
    echo "Creation du fichier ${documentRoot}/var/tree/${url}/${file}"

    echo $'<?php\n/********************************************************************' > ${documentRoot}/var/tree/${url}/${file}
    echo "*" >> ${documentRoot}/var/tree/${url}/${file}
    echo "* Generator : ZW3B v5.8.2" >> ${documentRoot}/var/tree/${url}/${file}
    echo "* Description : Web Sites Management System" >> ${documentRoot}/var/tree/${url}/${file}
    echo "* File : /var/tree/${url}/${file}" >> ${documentRoot}/var/tree/${url}/${file}
    echo "* Date : ${DATEFR}" >> ${documentRoot}/var/tree/${url}/${file}
    echo "*" >> ${documentRoot}/var/tree/${url}/${file}
    echo "************************************/" >> ${documentRoot}/var/tree/${url}/${file}
    echo $'' >> ${documentRoot}/var/tree/${url}/${file}

#    echo $'<?php\n# Fichier creer dynamiquement\n' > ${documentRoot}/var/tree/${url}/${file}

    echo "\$info=array();" >> ${documentRoot}/var/tree/${url}/${file}
    echo $'' >> ${documentRoot}/var/tree/${url}/${file}

    echo "\$info['id']=\"1\";" >> ${documentRoot}/var/tree/${url}/${file}
    echo "\$info['id_parent']=\"0\";" >> ${documentRoot}/var/tree/${url}/${file}
    echo "\$info['visibility']=\"0\";" >> ${documentRoot}/var/tree/${url}/${file}
    echo "\$info['uri']=\"//${url}\";" >> ${documentRoot}/var/tree/${url}/${file}
    
    echo "\$info['name']=\"${name}\";" >> ${documentRoot}/var/tree/${url}/${file}
    echo "\$info['description']=\"${desc}\";" >> ${documentRoot}/var/tree/${url}/${file}
    echo "\$info['text']=\"${text}\";" >> ${documentRoot}/var/tree/${url}/${file}
    echo "\$info['keywords']=\"${keywords}\";" >> ${documentRoot}/var/tree/${url}/${file}
    echo "\$info['photo']=array(0=>array('name'=>'','file'=>''));" >> ${documentRoot}/var/tree/${url}/${file}

    echo "\$info['skin']=\"${theme}\";" >> ${documentRoot}/var/tree/${url}/${file}
    echo "\$info['pagelayout']=\"pagelayout.tpl.php\";" >> ${documentRoot}/var/tree/${url}/${file}
    echo "\$info['override']=\"\";" >> ${documentRoot}/var/tree/${url}/${file}
    echo "\$info['modele']=\"${model}\";" >> ${documentRoot}/var/tree/${url}/${file}

    echo $'\n\n?>' >> ${documentRoot}/var/tree/${url}/${file}

    /bin/chown -R kss.www-data ${documentRoot}/var/tree/${url}/${file}
    /bin/chmod -R g+w ${documentRoot}/var/tree/${url}/${file}

#    echo 'Creation du repertoire des donnees en ecriture    ./var/tree/admin/'
#    mkdir ${documentRoot}/var/tree/ && chmod 777 ${documentRoot}/var/tree/admin/
}

function install_default_tree_zones()
{
    # zones
    zone=${model}
    linksym=zones.gen.php
    
    echo "";
    echo "Creation du lien symbolique                       ${zone} -> ./zones.gen.php"
#    /bin/ln -snf ${documentRoot}/var/zones/${zone} ${documentRoot}/var/tree/${url}/${linksym}
#    /bin/ln -snf ../../zones/${zone} ${documentRoot}/var/tree/${url}/${linksym}
    /bin/cp ${documentRoot}/var/zones/${zone} ${documentRoot}/var/tree/${url}/${linksym}
}



function install_default_config()
{
    file=config.inc.php
    # on crée le repertoire de config
    echo "";
    echo 'Creation du repertoire de configuration           ./config/'
    /bin/mkdir ${documentRoot}/config/    
    echo "Creation du fichier de configuration              ./config/${file}"
       

    echo $'<?php\n/********************************************************************' > ${documentRoot}/config/${file}
    echo "*" >> ${documentRoot}/config/${file}
    echo "* Generator : ZW3B v5.8.2" >> ${documentRoot}/config/${file}
    echo "* Description : Web Sites Management System" >> ${documentRoot}/config/${file}
    echo "* File : /var/tree/${url}/${file}" >> ${documentRoot}/config/${file}
    echo "* Date : ${DATEFR}" >> ${documentRoot}/config/${file}
    echo "*" >> ${documentRoot}/config/${file}
    echo "************************************/" >> ${documentRoot}/config/${file}
    echo $'' >> ${documentRoot}/config/${file}

    echo "\$conf=array();" >> ${documentRoot}/config/${file}
    echo $'' >> ${documentRoot}/config/${file}

    echo "// ZW3B.APPs -------------------------------------------------------" >> ${documentRoot}/config/${file}
    echo "\$conf['apps']=array();" >> ${documentRoot}/config/${file}
    echo "\$conf['apps']['conf']=array();" >> ${documentRoot}/config/${file}
    echo "\$conf['apps']['conf']['title']=\"ZW3B\";" >> ${documentRoot}/config/${file}
    echo "\$conf['apps']['conf']['desc']=\"Web Sites Management System (WSMS)\";" >> ${documentRoot}/config/${file}
    echo "\$conf['apps']['conf']['vs']=\"5.8.2\";" >> ${documentRoot}/config/${file}
#    echo "\$conf['apps']['conf']['rootdir']=\"/var/pro/web_apps/zw3b/current/\";" >> ${documentRoot}/config/${file}
    echo "\$conf['apps']['conf']['rootdir']=\"${documentRoot}\";" >> ${documentRoot}/config/${file}
#    echo "\$conf['apps']['conf']['url']=\"//apps.zw3b.fr\";" >> ${documentRoot}/config/${file}
    echo "\$conf['apps']['conf']['url']=\"//${url}\";" >> ${documentRoot}/config/${file}
    echo "//------------------------------------------------------------------" >> ${documentRoot}/config/${file}
    echo $'' >> ${documentRoot}/config/${file}

    echo "// ZW3B.HOST -------------------------------------------------------" >> ${documentRoot}/config/${file}
    echo "\$conf['host']=array();" >> ${documentRoot}/config/${file}
    echo "\$conf['host']['documentroot']=\"${documentRoot}\";" >> ${documentRoot}/config/${file}
    echo "\$conf['host']['uri']=\"//${url}\";" >> ${documentRoot}/config/${file}
    echo "\$conf['host']['title']=\"${name}\";" >> ${documentRoot}/config/${file}
    echo "\$conf['host']['description']=\"${desc}\";" >> ${documentRoot}/config/${file}
    echo "\$conf['host']['keywords']=\"${keywords}\";" >> ${documentRoot}/config/${file}
    echo "\$conf['host']['text']=\"${text}\";" >> ${documentRoot}/config/${file}
    echo "//------------------------------------------------------------------" >> ${documentRoot}/config/${file}
    echo $'' >> ${documentRoot}/config/${file}

    echo "// ZW3B.BDD -------------------------------------------------------" >> ${documentRoot}/config/${file}
    echo "\$conf['bdd']=array();" >> ${documentRoot}/config/${file}
    echo "\$conf['bdd']['host']=\"localhost\";" >> ${documentRoot}/config/${file}
    echo "\$conf['bdd']['db']=\"zw3b_site_v5_8_2\";" >> ${documentRoot}/config/${file}
    echo "\$conf['bdd']['usr']=\"root\";" >> ${documentRoot}/config/${file}
    echo "\$conf['bdd']['pwd']=\"\";" >> ${documentRoot}/config/${file}
    echo "//------------------------------------------------------------------" >> ${documentRoot}/config/${file}
    echo $'' >> ${documentRoot}/config/${file}

    echo "// ZW3B.STRUCTURE -------------------------------------------------------" >> ${documentRoot}/config/${file}
    echo "\$conf['structure']=array();" >> ${documentRoot}/config/${file}
    echo "\$conf['structure']['modele']=\"${model}\";" >> ${documentRoot}/config/${file}
    echo "\$conf['structure']['pagelayout']=\"pagelayout.tpl.php\";" >> ${documentRoot}/config/${file}
    echo "\$conf['structure']['override']=\"\";" >> ${documentRoot}/config/${file}
    echo "//------------------------------------------------------------------" >> ${documentRoot}/config/${file}
    echo $'' >> ${documentRoot}/config/${file}

    echo "// ZW3B.SKIN -------------------------------------------------------" >> ${documentRoot}/config/${file}
    echo "\$conf['skin']=array();" >> ${documentRoot}/config/${file}
    echo "\$conf['skin']['uri']=\"${theme}\";" >> ${documentRoot}/config/${file}
    echo "//------------------------------------------------------------------" >> ${documentRoot}/config/${file}

    echo $'\n\n?>' >> ${documentRoot}/config/${file}

    /bin/chown -R kss.www-data ${documentRoot}/config/${file}
    /bin/chmod -R g+w ${documentRoot}/config/${file}
}


function install_default_tree_app()
{
    # on creait le repertoire des pages de lappli ZW3B.Site
    echo "";

    # zones
    echo "";
    echo "Creation du repertoire                            http://${url}/config/"
    /bin/cp -Rp ${ZW3B_TREE}config/  ${documentRoot}/var/tree/${url}/
    echo "Creation du repertoire                            http://$turl}/tree/"
    /bin/cp -Rp ${ZW3B_TREE}tree/  ${documentRoot}/var/tree/${url}/
    echo "Creation du repertoire                            http://${url}/usr/"
    /bin/cp -Rp ${ZW3B_TREE}usr/  ${documentRoot}/var/tree/${url}/
    echo "Creation du repertoire                            http://${url}/contents/"
    /bin/cp -Rp ${ZW3B_TREE}contents/  ${documentRoot}/var/tree/${url}/    


     ################################################################
    echo "Creation du repertoire                            http://${url}/contact/"
    /bin/cp -Rp ${ZW3B_TREE}contact/  ${documentRoot}/var/tree/${url}/
    echo "Creation du repertoire                            http://${url}/about/"
    /bin/cp -Rp ${ZW3B_TREE}about/  ${documentRoot}/var/tree/${url}/


}




function install_default_config_rub()
{

    echo "\$config['rub']=\"${rub}\";" >> ${documentRoot}/config/config.inc.php
}
#####-------------------------- FONCTIONS ----------------------------#####

#####-------------------------- START / STOP ----------------------------#####

case "$1" in
install)
	echo "$0 Starting"
	case "$2" in
	zw3b.fr|lab3w.fr)
		echo "$2 OK"
		configuration
		selection_theme
		selection_model
		selection_modules
#		selection_rubs
		configuration_check
		install_default
		install_default_ln
#		install_default_tmp
		install_default_var
		install_default_tree_info
		install_default_tree_zones
		install_default_tree_app
		install_default_config
	;;
	esac
;;
*)
	echo "usage : $0 install domain.tld www"
;;

esac


#####-------------------------- START / STOP ----------------------------#####
